# tildetown-handbook

This handbook aims to provide people with referenceable, educational
material related to interactions with
[tilde.town](https://tilde.town).

This handbook is for people with less of a technical background who
want to learn more about the interactions you can have while using
tilde.town.

# Table of contents

<!-- markdown-toc start - Don't edit this section. Run M-x markdown-toc-refresh-toc -->
- [Requirements](#requirements)
- [Conventions used in this handbook](#conventions-used-in-this-handbook)
- [Getting started](#getting-started)
    - [For macOS users](#for-macos-users)
    - [For Windows Subsystem for Linux users](#for-windows-subsystem-for-linux-users)
    - [For Ubuntu users](#for-ubuntu-users)
    - [For cmdr users](#for-cmdr-users)
    - [For PuTTY users](#for-putty-users)
    - [Testing out your command line interface](#testing-out-your-command-line-interface)

<!-- markdown-toc end -->

# Requirements

* Basic understanding of files and directories
* A UNIX-like environment, such as:
  * [Ubuntu](https://ubuntu.com/)
  * [Linux Mint](https://linuxmint.com/)
  * [Manjaro](https://manjaro.org/)
  * [Windows Subsystem for Linux](https://docs.microsoft.com/en-us/windows/wsl/install-win10)
  * [macOS](https://www.apple.com/macos/)
  * [Homebrew](https://brew.sh/)
  * [scoop.sh](https://scoop.sh/)
  * [Chocolatey](https://chocolatey.org/)
  * [cmdr](https://cmder.net/)
  * [Cygwin](https://www.cygwin.com/)
  * [PuTTY](https://www.chiark.greenend.org.uk/~sgtatham/putty/)
  * [and many more](https://distrowatch.com/)

# Conventions used in this handbook

* **Notes** signify additional information.
* **Tips** signify alternative methods to procedures.
* **Examples** provide a visual reference of how a procedure would be carried out in the real world.
* **Monospaced font** signifies directory names, file names, file contents, and commands.

# Getting started

One of tilde.town's goals is to transform the command line from a
scary-looking technical tool into a tool for creating beautiful
things.

Because of this, you will need to open your UNIX-like environment's
command line interface. For me, it's a little icon on my desktop that
looks like a blank, black screen, but it may be different for you.

I will list off how you can find your command line interface for a few
UNIX-like environments in the sections listed below, and then we will
test the environment to make sure everything is working.

- [For macOS users](#for-macos-users)
- [For Windows Subsystem for Linux users](#for-windows-subsystem-for-linux-users)
- [For Ubuntu users](#for-ubuntu-users)
- [For cmdr users](#for-cmdr-users)
- [For PuTTY users](#for-putty-users)
- [Testing out your command line interface](#testing-out-your-command-line-interface)

## For macOS users

You can use one of the following procedures below for finding the
built-in app called "Terminal":
  * Open the Spotlight app and search for the word "terminal"
  * Open your `Applications > Utilities` directory and double-click the Terminal app

## For Windows Subsystem for Linux users

* Open your start menu and search for the word "Ubuntu"

**Note**: The steps above assumed you chose Ubuntu as the Linux
distribution for Windows Subsystem for Linux during your installation.

## For Ubuntu users

You can use one of the following procedures below for finding the
built-in terminal application:
  * Type `Ctrl+Shift+t`
  * Click the Ubuntu icon and search for the word "terminal"

## For cmdr users

* Open the cmdr application

## For PuTTY users

* PuTTY isn't a command line interface itself, but it acts as a tool
  to connect to other computers, so you can use their command line
  interface. This will be covered in the
  [Connecting to tilde.town](#connecting-to-tildetown) section.

## Testing out your command line interface

After you think you have found your environment's command line
interface, you'll be using it in the rest of this handbook.

**Note**: I'll be calling the command line a "terminal" from now on.

As a test for good measure, let's try running our first command. Try
typing the following line into your terminal:

```
ls
```

That should "return" several items. For me, it returned:

```
Desktop Downloads Documents Images Videos Music
```

If `ls` returned what seems to be the files or directories on your
computer, then you have everything you need!

**Note**: "return" is technical jargon used to describe how something
on a computer sends data somewhere. In this case, the text
representing your files and directories is the data, and that text is
being sent to your screen.
